@@ -4,7 +4,7 @@ from typing import Optional, Literal, Annotated
 
 
 def main_public_from_parser(method: Annotated[Literal["symlink", "copy"], typer.Option(..., help="Method to use for setting up the config file.")],
-                            on_conflict: Annotated[Literal["throwError", "overwriteDefaultPath", "backupDefaultPath"], typer.Option(..., help="Action to take on conflict")],
+                            on_conflict: Annotated[Literal["throw-error", "overwriteDefaultPath", "backupDefaultPath"], typer.Option(..., help="Action to take on conflict")],
                             which: Annotated[Optional[str], typer.Option(..., help="Specific items to process")] = None,
                             interactive: Annotated[bool, typer.Option(..., help="Run in interactive mode")] = False):
     """Terminology:
@@ -32,7 +32,7 @@ def main_public_from_parser(method: Annotated[Literal["symlink", "copy"], typer.
 
 
 def main_private_from_parser(method: Annotated[Literal["symlink", "copy"], typer.Option(..., help="Method to use for linking files")],
-                             on_conflict: Annotated[Literal["throwError", "overwriteSelfManaged", "backupSelfManaged", "overwriteDefaultPath", "backupDefaultPath"], typer.Option(..., help="Action to take on conflict")] = "throwError",
+                             on_conflict: Annotated[Literal["throw-error", "overwriteSelfManaged", "backupSelfManaged", "overwriteDefaultPath", "backupDefaultPath"], typer.Option(..., help="Action to take on conflict")] = "throw-error",
                              which: Annotated[Optional[str], typer.Option(..., help="Specific items to process")] = None,
                              interactive: Annotated[bool, typer.Option(..., help="Run in interactive mode")] = False):
     from machineconfig.profile.create_links import ConfigMapper, read_mapper
