@@ -3,35 +3,42 @@ import typer
 from typing import Optional, Annotated
 
 
+def copy_both_assets():
+    import machineconfig.profile.create_helper as create_helper
+    create_helper.copy_assets_to_machine(which="scripts")
+    create_helper.copy_assets_to_machine(which="settings")
+
+
 def update(no_copy_assets: Annotated[bool, typer.Option("--no-assets-copy", "-na", help="Copy (overwrite) assets to the machine after the update")] = False):
     """🔄 UPDATE uv and machineconfig"""
     # from machineconfig.utils.source_of_truth import LIBRARY_ROOT
     # repo_root = LIBRARY_ROOT.parent.parent
     from pathlib import Path
     if Path.home().joinpath("code", "machineconfig").exists():
-        code = """
+        shell_script = """
 uv self update
 cd ~/code/machineconfig
 git pull
 uv tool install --upgrade --editable $HOME/code/machineconfig
     """
     else:
-        code = """
+        shell_script = """
 uv self update
 uv tool install --upgrade machineconfig
     """
     import platform
     if platform.system() == "Windows":
-        # from machineconfig.utils.code import run_shell_script_after_exit
-        # run_shell_script_after_exit(code)
-        print(f'please run {code} in powershell to update machineconfig')
+        from machineconfig.utils.code import exit_then_run_shell_script, get_uv_command_executing_python_script
+        from machineconfig.utils.meta import lambda_to_python_script
+        python_script = lambda_to_python_script(lambda: copy_both_assets(), in_global=True, import_module=False)
+        uv_command, _py_file = get_uv_command_executing_python_script(python_script=python_script, uv_with=["machineconfig"], uv_project_dir=None)
+        exit_then_run_shell_script(shell_script + "\n" + uv_command, strict=True)
     else:
         from machineconfig.utils.code import run_shell_script
-        run_shell_script(code)
+        run_shell_script(shell_script)
     if not no_copy_assets:
-        import machineconfig.profile.create_helper as create_helper
-        create_helper.copy_assets_to_machine(which="scripts")
-        create_helper.copy_assets_to_machine(which="settings")
+        copy_both_assets()
+
 def install(no_copy_assets: Annotated[bool, typer.Option("--no-assets-copy", "-na", help="Copy (overwrite) assets to the machine after the update")] = False):
     """📋 CLONE machienconfig locally and incorporate to shell profile for faster execution and nightly updates."""
     from machineconfig.utils.code import run_shell_script
@@ -41,9 +48,9 @@ def install(no_copy_assets: Annotated[bool, typer.Option("--no-assets-copy", "-n
     else:
         import platform
         if platform.system() == "Windows":
-            run_shell_script(r"""& "$HOME\.local\bin\uv.exe" tool install --upgrade "machineconfig>=6.81" """)
+            run_shell_script(r"""& "$HOME\.local\bin\uv.exe" tool install --upgrade "machineconfig>=6.96" """)
         else:
-            run_shell_script("""$HOME/.local/bin/uv tool install --upgrade "machineconfig>=6.81" """)
+            run_shell_script("""$HOME/.local/bin/uv tool install --upgrade "machineconfig>=6.96" """)
     from machineconfig.profile.create_shell_profile import create_default_shell_profile
     if not no_copy_assets:
         create_default_shell_profile()   # involves copying assets too
@@ -68,7 +75,7 @@ def navigate():
     path = Path(navigator.__file__).resolve().parent.joinpath("devops_navigator.py")
     from machineconfig.utils.code import run_shell_script
     if Path.home().joinpath("code/machineconfig").exists(): executable = f"""--project "{str(Path.home().joinpath("code/machineconfig"))}" --with textual"""
-    else: executable = """--with "machineconfig>=6.81,textual" """
+    else: executable = """--with "machineconfig>=6.96,textual" """
     run_shell_script(f"""uv run {executable} {path}""")
 
 
