@@ -7,18 +7,23 @@ from pathlib import Path
 
 def print_code(code: str, lexer: str, desc: str, subtitle: str = ""):
     import platform
-    from rich.console import Console
-    from rich.panel import Panel
-    from rich.syntax import Syntax
-    if lexer == "shell":
-        if platform.system() == "Windows":
-            lexer = "powershell"
-        elif platform.system() in ["Linux", "Darwin"]:
-            lexer = "sh"
-        else:
-            raise NotImplementedError(f"Platform {platform.system()} not supported for lexer {lexer}")
-    console = Console()
-    console.print(Panel(Syntax(code=code, lexer=lexer), title=f"📄 {desc}", subtitle=subtitle), style="bold red")
+    try:
+        from rich.console import Console
+        from rich.panel import Panel
+        from rich.syntax import Syntax
+        if lexer == "shell":
+            if platform.system() == "Windows":
+                lexer = "powershell"
+            elif platform.system() in ["Linux", "Darwin"]:
+                lexer = "sh"
+            else:
+                raise NotImplementedError(f"Platform {platform.system()} not supported for lexer {lexer}")
+        console = Console()
+        console.print(Panel(Syntax(code=code, lexer=lexer), title=f"📄 {desc}", subtitle=subtitle), style="bold red")
+    except ImportError:
+        print(f"--- {desc} ---")
+        print(code)
+        print(f"--- End of {desc} ---")
 
 
 def get_uv_command_executing_python_script(python_script: str, uv_with: Optional[list[str]], uv_project_dir: Optional[str]) -> tuple[str, Path]:
@@ -51,7 +56,7 @@ def run_python_script_in_marimo(py_script: str, uv_project_with: Optional[str]):
     if uv_project_with is not None:
         requirements = f"""--with "marimo" --project {uv_project_with} """
     else:
-        requirements = f"""--with "marimo" """
+        requirements = """--with "marimo" """
     fire_line = f"""
 cd {tmp_dir}
 uv run {requirements} marimo convert {pyfile.name} -o marimo_nb.py
@@ -77,38 +82,55 @@ def run_shell_script(script: str, display_script: bool = True, clean_env: bool =
         lexer = "bash"
     with tempfile.NamedTemporaryFile(mode='w', suffix=suffix, delete=False, encoding='utf-8') as temp_file:
         temp_file.write(script)
-        temp_script_path = Path(temp_file.name)
+        temp_shell_script_path = Path(temp_file.name)
     console = Console()
     if display_script:
         from rich.syntax import Syntax
-        console.print(Panel(Syntax(code=script, lexer=lexer), title=f"📄 shell script @ {temp_script_path}", subtitle="shell script being executed"), style="bold red")
+        console.print(Panel(Syntax(code=script, lexer=lexer), title=f"📄 shell script @ {temp_shell_script_path}", subtitle="shell script being executed"), style="bold red")
     env = {} if clean_env else None
     if platform.system() == "Windows":
         import subprocess
-        proc = subprocess.run(f'powershell -ExecutionPolicy Bypass -File "{temp_script_path}"', check=True, shell=True, env=env)
+        proc = subprocess.run(f'powershell -ExecutionPolicy Bypass -File "{temp_shell_script_path}"', check=True, shell=True, env=env)
     elif platform.system() == "Linux" or platform.system() == "Darwin":
         import subprocess
-        proc = subprocess.run(f"bash {str(temp_script_path)}", check=True, shell=True, env=env)
+        proc = subprocess.run(f"bash {str(temp_shell_script_path)}", check=True, shell=True, env=env)
     else:
         raise NotImplementedError(f"Platform {platform.system()} not supported.")
     # console.print(f"✅  [green]Script executed successfully:[/green] [blue]{temp_script_path}[/blue]")
     if proc.returncode != 0:
-        console.print(f"❌  [red]Script execution failed with return code {proc.returncode}:[/red] [blue]{temp_script_path}[/blue]")
+        console.print(f"❌  [red]Script execution failed with return code {proc.returncode}:[/red] [blue]{temp_shell_script_path}[/blue]")
     elif proc.returncode == 0:
-        console.print(f"✅  [green]Script executed successfully:[/green] [blue]{temp_script_path}[/blue]")
+        console.print(f"✅  [green]Script executed successfully:[/green] [blue]{temp_shell_script_path}[/blue]")
     else:
-        console.print(f"⚠️  [yellow]Script executed with warnings (return code {proc.returncode}):[/yellow] [blue]{temp_script_path}[/blue]")    
-    temp_script_path.unlink(missing_ok=True)
-    console.print(f"🗑️  [blue]Temporary script deleted:[/blue] [green]{temp_script_path}[/green]")
+        console.print(f"⚠️  [yellow]Script executed with warnings (return code {proc.returncode}):[/yellow] [blue]{temp_shell_script_path}[/blue]")
+    temp_shell_script_path.unlink(missing_ok=True)
+    console.print(f"🗑️  [blue]Temporary script deleted:[/blue] [green]{temp_shell_script_path}[/green]")
     return proc
 
 
-def exit_then_run_shell_script(script: str):
+def exit_then_run_shell_script(script: str, strict: bool = False):
     import os
     op_program_path = os.environ.get("OP_PROGRAM_PATH", None)
+    if strict and op_program_path is None:
+        import platform
+        if platform.system() == "Windows":
+            suffix = ".ps1"
+            lexer = "powershell"
+        else:
+            suffix = ".sh"
+            lexer = "bash"
+        op_program_path = Path.home().joinpath("tmp_results", "tmp_scripts", "manual_run", f"manual_script_{randstr()}.{suffix}")
+        op_program_path.parent.mkdir(parents=True, exist_ok=True)
+        op_program_path.write_text(script, encoding="utf-8")
+        print_code(script, lexer=lexer, desc="script to run manually")
+        print(f"Please run the script manually via your shell by executing the script @:\n{str(op_program_path)}")
+        print("OP_PROGRAM_PATH environment variable is not set in strict mode.")
     if op_program_path is not None:
         op_program_path = Path(op_program_path)
         op_program_path.parent.mkdir(parents=True, exist_ok=True)
         op_program_path.write_text(script, encoding="utf-8")
+        print(f"Handing over to shell script runner via OP_PROGRAM_PATH @\n{str(op_program_path)}...")
     else:
         run_shell_script(script)
+    import sys
+    sys.exit(0)
